==> scodec-bits_2.11-1.1.19-sources.jar: scodec/bits/ByteOrdering.scala <==
/*
 * Copyright (c) 2013, Scodec
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its contributors
 *    may be used to endorse or promote products derived from this software without
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package scodec.bits

import java.nio.ByteOrder

/** Enumeration of byte ordering. */
sealed trait ByteOrdering {
  def toJava: ByteOrder
}

/** Companion for [[ByteOrdering]]. */
object ByteOrdering {

  /**
    * Converts the specified byte order to a [[ByteOrdering]].
    * @throws IllegalArgumentException if the order cannot be converted
    */
  def fromJava(bo: ByteOrder): ByteOrdering =
    if (bo == ByteOrder.BIG_ENDIAN) ByteOrdering.BigEndian
    else if (bo == ByteOrder.LITTLE_ENDIAN) ByteOrdering.LittleEndian
    else throw new IllegalArgumentException("unknown byte order " + bo)

  /** Byte ordering where the most significant byte is at the smallest address. */
  case object BigEndian extends ByteOrdering {
    def toJava = ByteOrder.BIG_ENDIAN
  }

  /** Byte ordering where the least significant byte is at the smallest address. */
  case object LittleEndian extends ByteOrdering {
    def toJava = ByteOrder.LITTLE_ENDIAN
  }
}

==> scodec-bits_2.11-1.1.27-sources.jar: scodec/bits/ByteOrdering.scala <==
/*
 * Copyright (c) 2013, Scodec
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its contributors
 *    may be used to endorse or promote products derived from this software without
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package scodec.bits

import java.nio.ByteOrder

/** Enumeration of byte ordering. */
sealed trait ByteOrdering {
  def toJava: ByteOrder
}

/** Companion for [[ByteOrdering]]. */
object ByteOrdering {

  /** Converts the specified byte order to a [[ByteOrdering]].
    * @throws IllegalArgumentException if the order cannot be converted
    */
  def fromJava(bo: ByteOrder): ByteOrdering =
    if (bo == ByteOrder.BIG_ENDIAN) ByteOrdering.BigEndian
    else if (bo == ByteOrder.LITTLE_ENDIAN) ByteOrdering.LittleEndian
    else throw new IllegalArgumentException("unknown byte order " + bo)

  /** Byte ordering where the most significant byte is at the smallest address. */
  case object BigEndian extends ByteOrdering {
    def toJava = ByteOrder.BIG_ENDIAN
  }

  /** Byte ordering where the least significant byte is at the smallest address. */
  case object LittleEndian extends ByteOrdering {
    def toJava = ByteOrder.LITTLE_ENDIAN
  }
}
